@@ -11,15 +11,21 @@ testthat::skip_if_not_installed("arrow")
 test_that("add_labels_mortality", {
 
   # sem labels
-  test1a <- read_mortality(year = 2010, add_labels = NULL, columns = c('abbrev_state', 'V0704')) |>
-            filter(abbrev_state == 'RO')
+  test1a <- read_mortality(year = 2010,
+                           add_labels = NULL,
+                           columns = c('abbrev_state', 'V0704'),
+                           showProgress = FALSE) |>
+            dplyr::filter(abbrev_state == 'RO')
 
   # com labels
-  test1b <- censobr:::add_labels_mortality(arrw = test1a, year=2010, lang = 'pt') |>
-            filter(abbrev_state == 'RO')
+  test1b <- censobr:::add_labels_mortality(arrw = test1a,
+                                           year=2010,
+                                           lang = 'pt') |>
+            dplyr::filter(abbrev_state == 'RO')
+
+  test1a <- dplyr::collect(test1a)
+  test1b <- dplyr::collect(test1b)
 
-  test1a <- as.data.frame(test1a)
-  test1b <- as.data.frame(test1b)
   # add labels
   testthat::expect_true('1' %in% test1a$V0704)
   testthat::expect_true('Feminino' %in% test1b$V0704)
